==> rice-it-internal-tools-2.1.14-sources.jar: org/kuali/rice/test/persistence/PersistenceTestHelper.java <==
package org.kuali.rice.test.persistence;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class PersistenceTestHelper
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public PersistenceTestHelper
(java.lang.String dsName) {}
public  java.lang.Object assertRow(java.util.Map fields, java.lang.Object table, java.lang.Object pk) { return null;}
public  java.lang.Object assertRow(java.util.Map fields, java.lang.Object table) { return null;}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  org.kuali.rice.krad.service.BusinessObjectService getBoService() { return (org.kuali.rice.krad.service.BusinessObjectService)null;}
public  void setBoService(org.kuali.rice.krad.service.BusinessObjectService value) { }
public  javax.sql.DataSource getDatasource() { return (javax.sql.DataSource)null;}
public  void setDatasource(javax.sql.DataSource value) { }
public  java.lang.Object bool(java.lang.Object value, java.lang.Object column) { return null;}
public  java.lang.Object default_field(java.lang.Object bo) { return null;}
public  java.lang.Object active_field(java.lang.Object bo) { return null;}
public  java.lang.Object edit_field(java.lang.Object bo) { return null;}
public  java.lang.Object basic_fields(org.kuali.rice.krad.bo.PersistableBusinessObject bo) { return null;}
public  java.lang.Object standard_fields(org.kuali.rice.krad.bo.PersistableBusinessObject bo) { return null;}
public  java.lang.Object genDbTimestamp() { return null;}
public  java.lang.Object toDbTimestamp(org.joda.time.DateTime datetime) { return null;}
public  java.lang.Object toDbTimestamp(long millis) { return null;}
public  java.lang.Object assertRow(java.util.Map fields, java.lang.Object table, java.lang.Object pk, java.lang.Object ignore) { return null;}
}

==> rice-it-internal-tools-2.5.11-sources.jar: org/kuali/rice/test/persistence/PersistenceTestHelper.java <==
package org.kuali.rice.test.persistence;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@java.lang.Deprecated() public class PersistenceTestHelper
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public PersistenceTestHelper
(java.lang.String dsName) {}
public  java.lang.Object assertRow(java.util.Map fields, java.lang.Object table, java.lang.Object pk) { return null;}
public  java.lang.Object assertRow(java.util.Map fields, java.lang.Object table) { return null;}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  org.kuali.rice.krad.service.BusinessObjectService getBoService() { return (org.kuali.rice.krad.service.BusinessObjectService)null;}
public  void setBoService(org.kuali.rice.krad.service.BusinessObjectService value) { }
public  javax.sql.DataSource getDatasource() { return (javax.sql.DataSource)null;}
public  void setDatasource(javax.sql.DataSource value) { }
public  java.lang.Object bool(java.lang.Object value, java.lang.Object column) { return null;}
public  java.lang.Object default_field(java.lang.Object bo) { return null;}
public  java.lang.Object active_field(java.lang.Object bo) { return null;}
public  java.lang.Object edit_field(java.lang.Object bo) { return null;}
public  java.lang.Object basic_fields(org.kuali.rice.krad.bo.PersistableBusinessObject bo) { return null;}
public  java.lang.Object standard_fields(org.kuali.rice.krad.bo.PersistableBusinessObject bo) { return null;}
public  java.lang.Object genDbTimestamp() { return null;}
public  java.lang.Object toDbTimestamp(org.joda.time.DateTime datetime) { return null;}
public  java.lang.Object toDbTimestamp(long millis) { return null;}
public  java.lang.Object assertRow(java.util.Map fields, java.lang.Object table, java.lang.Object pk, java.lang.Object ignore) { return null;}
}
